/// <reference types="node" />
import { type SocketType } from "dgram";
export declare type GetTimeOptions = Readonly<{
    /**
     * NTP server address
     * @default "pool.ntp.org"
     */
    server?: string;
    /**
     * NTP server port
     *
     * @default 123
     */
    port?: number;
    /**
     * Timeout in milliseconds
     * @default 5000
     */
    timeout?: number;
    /**
     * UDP Socket type (IP)
     * @default "udp4"
     */
    socketType?: SocketType;
    /**
     * Whether sync with UTC or Local time
     * @default true
     */
    utc?: boolean;
}>;
/**
 *
 *
 * @export
 * @param {GetTimeOptions} [options={}]
 * @param {string} [options.server="pool.ntp.org"] NTP server address
 * @param {number} [options.port=123] NTP server port
 * @param {number} [options.timeout=5000] Timeout in milliseconds
 * @param {SocketType} [options.socketType="udp4"] UDP Socket type (IP)
 * @param {boolean} [options.utc=true] Whether use UTC or Local time
 * @return {Promise<Date>} Synced date
 */
export declare function getTime({ server, port, timeout, socketType, utc, }?: GetTimeOptions): Promise<Date>;
